@@ -3,7 +3,11 @@ import sys
 from io import BufferedIOBase
 from urllib.error import URLError
 from urllib.request import (
-    build_opener, BaseHandler, FileHandler, HTTPHandler, HTTPSHandler
+    build_opener,
+    BaseHandler,
+    FileHandler,
+    HTTPHandler,
+    HTTPSHandler,
 )
 from urllib.response import addinfourl
 
@@ -25,7 +29,7 @@ class ResourceHandler(BaseHandler):
             selector = req.selector
         except AttributeError:
             selector = req.get_selector()
-        resource_name = selector.lstrip('/')
+        resource_name = selector.lstrip("/")
         pkg_name = req.host
 
         stream = pkg_resources.resource_stream(pkg_name, resource_name)
@@ -37,14 +41,15 @@ class PythonPathHandler(BaseHandler):
     """
     a filename with relative path to the pythonpath
     """
+
     def __init__(self):
         pass
 
     def pythonpath_open(self, req):
-        pathname = req.get_full_url()[len(req.type + ':'):].lstrip('/')
+        pathname = req.get_full_url()[len(req.type + ":") :].lstrip("/")
         full_path = self._find(pathname)
 
-        return addinfourl(open(full_path, 'r'), [], req.get_full_url())
+        return addinfourl(open(full_path, "r"), [], req.get_full_url())
 
     @staticmethod
     def _find(pathname):
@@ -56,12 +61,17 @@ class PythonPathHandler(BaseHandler):
 
 
 handlers = [
-    FileHandler, HTTPHandler, HTTPSHandler, PythonPathHandler, ResourceHandler
+    FileHandler,
+    HTTPHandler,
+    HTTPSHandler,
+    PythonPathHandler,
+    ResourceHandler,
 ]
 
 try:
     # noinspection PyUnresolvedReferences
     from . import k8s
+
     handlers.append(k8s.K8SHandler)
 except ImportError:
     pass
@@ -69,6 +79,7 @@ except ImportError:
 try:
     # noinspection PyUnresolvedReferences
     from . import aws
+
     handlers.append(aws.S3Handler)
     handlers.append(aws.SecretsManagerHandler)
 except ImportError:
@@ -77,6 +88,7 @@ except ImportError:
 try:
     # noinspection PyUnresolvedReferences
     from . import ali
+
     handlers.append(ali.OSSHandler)
 except ImportError:
     pass
